pyRepRapComm
-------------------

A simple python modules for communicating with printers that run RepRapFirmware (Such as the Duet series boards)

I developed this in support of building a status screen for my HyperCube Evo printer and didn't want to spend the money on a PanelDue.   

Info on status information returned can be found here: https://reprap.org/wiki/RepRap_Firmware_Status_responses#Extended_Config_Response


